@@ -24,6 +24,7 @@
 
 #pylint:disable=useless-super-delegation
 
+from django.utils.translation import ugettext_lazy as _
 from rest_framework import status
 from rest_framework.exceptions import ValidationError
 from rest_framework.generics import (RetrieveAPIView,
@@ -31,8 +32,9 @@ from rest_framework.generics import (RetrieveAPIView,
 from rest_framework.response import Response
 
 from ..backends import ProcessorError
-from ..docs import swagger_auto_schema
+from ..docs import swagger_auto_schema, Parameter, IN_PATH
 from ..mixins import OrganizationMixin
+from ..models import get_broker
 from .serializers import (BankSerializer, CardSerializer,
     CardTokenSerializer)
 
@@ -85,6 +87,12 @@ class PaymentMethodDetailAPIView(OrganizationMixin,
     Pass through to the processor to retrieve some details about
     the payment method (ex: credit card) associated to a subscriber.
 
+    When you wish to update the payment method on file through
+    a Strong Customer Authentication (SCA) workflow, the payment processor
+    will require a token generated by the server. That token can be retrieved
+    in the processor.STRIPE_INTENT_SECRET field when the API is called
+    with `?update=1` query parameters.
+
     **Tags**: billing
 
     **Examples**
@@ -122,6 +130,14 @@ class PaymentMethodDetailAPIView(OrganizationMixin,
         return super(PaymentMethodDetailAPIView, self).delete(
             request, *args, **kwargs)
 
+    @swagger_auto_schema(
+        manual_parameters=[
+            Parameter('update', IN_PATH, type='bool')
+        ])
+    def get(self, request, *args, **kwargs):
+        return super(PaymentMethodDetailAPIView, self).get(
+            request, *args, **kwargs)
+
     @swagger_auto_schema(request_body=CardTokenSerializer)
     def put(self, request, *args, **kwargs):
         """
@@ -159,19 +175,34 @@ class PaymentMethodDetailAPIView(OrganizationMixin,
     def destroy(self, request, *args, **kwargs):
         #pylint:disable=unused-argument
         self.organization.delete_card()
-        return Response(status=status.HTTP_204_NO_CONTENT)
+        return Response({
+            'detail': _("Your credit card is no longer on file with us.")},
+            status=status.HTTP_200_OK)
 
     def retrieve(self, request, *args, **kwargs):
         #pylint:disable=unused-argument
-        return Response(self.organization.retrieve_card())
+        resp_data = self.organization.retrieve_card()
+        if request.query_params.get('update', False):
+            resp_data.update({
+                'processor':
+                self.organization.processor_backend.get_payment_context(
+                    get_broker(),
+                    self.organization.processor_card_key,
+                    subscriber_email=self.organization.email,
+                    subscriber_slug=self.organization.slug)
+            })
+        return Response(resp_data)
 
     def update(self, request, *args, **kwargs):
+        #pylint:disable=unused-argument
         partial = kwargs.pop('partial', False)
         serializer = CardTokenSerializer(data=request.data, partial=partial)
         serializer.is_valid(raise_exception=True)
         token = serializer.validated_data['token']
         try:
-            self.organization.update_card(token, self.request.user)
+            new_card = self.organization.update_card(token, self.request.user)
         except ProcessorError as err:
             raise ValidationError(err)
-        return self.retrieve(request, *args, **kwargs)
+        new_card.update({
+            'detail': _("Your credit card on file was sucessfully updated.")})
+        return Response(new_card)
