@@ -43,7 +43,6 @@ from django.contrib.auth.hashers import is_password_usable
 from django.db import transaction
 from django.template.defaultfilters import slugify
 from django.utils.translation import ugettext_lazy as _
-from django.urls.exceptions import NoReverseMatch
 from django_countries.serializer_fields import CountryField
 from rest_framework import serializers
 from rest_framework.exceptions import ValidationError
@@ -56,7 +55,7 @@ from ..decorators import _valid_manager
 from ..humanize import as_money
 from ..mixins import as_html_description, product_url
 from ..models import (AdvanceDiscount, BalanceLine, CartItem, Charge, Coupon,
-    Plan, RoleDescription, Subscription, Transaction)
+    Plan, RoleDescription, Subscription, Transaction, get_broker)
 from ..utils import (build_absolute_uri, get_organization_model, get_role_model)
 
 #pylint: disable=no-init
@@ -185,10 +184,22 @@ class BankSerializer(NoModelSerializer):
         help_text=_("Three-letter ISO 4217 code for currency unit (ex: usd)"))
 
 
+class ProcessorAuthSerializer(NoModelSerializer):
+
+    STRIPE_PUB_KEY = serializers.CharField(required=False,
+        help_text=_("Processor public key (Stripe)"))
+    STRIPE_INTENT_SECRET = serializers.CharField(required=False,
+        help_text=_("PaymentIntent or SetupIntent secret for SCA (Stripe)"))
+    STRIPE_ACCOUNT = serializers.CharField(required=False,
+        help_text=_("Connected account identifier (Stripe)"))
+
+
 class CardSerializer(NoModelSerializer):
     """
     Information to verify a credit card
     """
+    processor = ProcessorAuthSerializer(required=False,
+      help_text=_("Keys to authenticate the client with the payment processor"))
     last4 = serializers.CharField(
         help_text=_("Last 4 digits of the credit card on file"))
     exp_date = serializers.CharField(
@@ -227,6 +238,8 @@ class ChargeSerializer(serializers.ModelSerializer):
         help_text=_("Amount and unit in a commonly accepted readable format"))
     detail = serializers.CharField(read_only=True, required=False,
         help_text=_("Feedback for the user in plain text"))
+    last4 = serializers.CharField(source='get_last4_display', read_only=True,
+        help_text=_("Last 4 digits of the credit card used"))
 
     @staticmethod
     def get_readable_amount(charge):
@@ -235,9 +248,11 @@ class ChargeSerializer(serializers.ModelSerializer):
     class Meta:
         model = Charge
         fields = ('created_at', 'amount', 'unit', 'readable_amount',
-                  'description', 'last4', 'exp_date', 'processor_key', 'state',
-                  'detail')
-        read_only_fields = ('detail',)
+            'description', 'last4', 'exp_date', 'processor_key', 'state',
+            'detail')
+        read_only_fields = ('created_at', 'amount', 'unit', 'readable_amount',
+            'description', 'last4', 'exp_date', 'processor_key', 'state',
+            'detail')
 
 
 class CouponCreateSerializer(serializers.ModelSerializer):
@@ -405,12 +420,17 @@ class OrganizationDetailSerializer(OrganizationSerializer):
     extra = serializers.CharField(required=False, allow_null=True,
         help_text=_("Extra meta data (can be stringify JSON)"))
 
+    detail = serializers.CharField(required=False,
+        help_text=_("Describes the result of the action"\
+            " in human-readable form"))
+
     class Meta(OrganizationSerializer.Meta):
         fields = OrganizationSerializer.Meta.fields + (
             'created_at', 'email', 'phone',
             'street_address', 'locality', 'region', 'postal_code', 'country',
-            'default_timezone', 'is_provider', 'is_bulk_buyer', 'extra')
-        read_only_fields = ('created_at',)
+            'default_timezone', 'is_provider', 'is_bulk_buyer', 'extra',
+            'detail')
+        read_only_fields = ('created_at', 'detail')
 
 
 class OrganizationCreateSerializer(NoModelSerializer):
@@ -557,6 +577,10 @@ class PlanSerializer(serializers.ModelSerializer):
     is_cart_item = serializers.SerializerMethodField(required=False,
         help_text=_("The plan is part of the cart to checkout"))
 
+    detail = serializers.CharField(required=False,
+        help_text=_("Describes the result of the action"\
+            " in human-readable form"))
+
     class Meta:
         model = Plan
         fields = ('slug', 'title', 'description', 'is_active',
@@ -565,9 +589,9 @@ class PlanSerializer(serializers.ModelSerializer):
                   'period_length', 'renewal_type', 'is_not_priced',
                   'created_at',
                   'skip_optin_on_grant', 'optin_on_request',
-                  'discounted_period_amount', 'is_cart_item')
+                  'discounted_period_amount', 'is_cart_item', 'detail')
         read_only_fields = ('slug', 'app_url',
-            'discounted_period_amount', 'is_cart_item')
+            'discounted_period_amount', 'is_cart_item', 'detail')
 
     @staticmethod
     def get_discounted_period_amount(obj):
@@ -709,6 +733,31 @@ class TransactionSerializer(serializers.ModelSerializer):
             'dest_account', 'dest_organization', 'dest_amount', 'dest_unit')
 
 
+class CreateOfflineTransactionSerializer(NoModelSerializer):
+    """
+    Serializer to validate the input that creates an off-line transaction.
+    """
+    subscription = serializers.CharField(
+        help_text="The subscription the offline transaction refers to.")
+    created_at = serializers.DateTimeField(
+        help_text=_("Date/time of creation (in ISO format)"))
+    # XXX Shouldn't this be same format as TransactionSerializer.amount?
+    amount = serializers.DecimalField(None, 2)
+    descr = serializers.CharField(required=False,
+        help_text=_("Free-form text description for the %(object)s") % {
+            'object': 'transaction'})
+
+
+class OfflineTransactionSerializer(NoModelSerializer):
+    """
+    Serializer to format the output of importing an off-line transaction.
+    """
+    detail = serializers.CharField(required=False,
+        help_text=_("Describes the result of the action"\
+            " in human-readable form"))
+    results = TransactionSerializer(many=True)
+
+
 class UserSerializer(serializers.ModelSerializer):
 
     # Only way I found out to remove the ``UniqueValidator``. We are not
@@ -821,13 +870,8 @@ class AccessibleSerializer(serializers.ModelSerializer):
         return settings_location
 
     def get_home_url(self, obj):
-        try:
-            return build_absolute_uri(self.context['request'], location=reverse(
-                'organization_app', args=(obj.organization.slug,)))
-        except NoReverseMatch:
-            # serializer used in djaodjin-saas not in djaoapp
-            pass
-        return None
+        return product_url(get_broker(), subscriber=obj.organization,
+            request=self.context['request'])
 
 
 class RoleSerializer(serializers.ModelSerializer):
@@ -838,12 +882,17 @@ class RoleSerializer(serializers.ModelSerializer):
     accept_request_api_url = serializers.SerializerMethodField()
     remove_api_url = serializers.SerializerMethodField()
 
+    detail = serializers.CharField(required=False,
+        help_text=_("Describes the result of the action"\
+            " in human-readable form"))
+
     class Meta:
         model = get_role_model()
         fields = ('created_at', 'user', 'grant_key',
             'organization', 'role_description', 'accept_request_api_url',
-            'remove_api_url')
-        read_only_fields = ('created_at', 'grant_key', 'role_description')
+            'remove_api_url', 'detail')
+        read_only_fields = ('created_at', 'grant_key', 'role_description',
+            'detail')
 
     def get_accept_request_api_url(self, obj):
         if obj.request_key:
