@@ -207,9 +207,14 @@ def extend_subscriptions(at_time=None, dry_run=False):
     for subscription in Subscription.objects.valid_for(
             auto_renew=True, created_at__lte=at_time, ends_at__gt=at_time):
         lower, upper = subscription.clipped_period_for(at_time)
-        LOGGER.debug("at_time (%s) in period [%s, %s[ of %s ending at %s",
-            at_time, lower, upper, subscription, subscription.ends_at)
-        days_from_end = relativedelta(subscription.ends_at, at_time).days
+        # `relativedelta` will compute number of years, months, days, etc.
+        # `days` represents the difference in days after years and months have
+        # been substracted instead of a total number of days as `timedelta`
+        # does.
+        days_from_end = (subscription.ends_at - at_time).days
+        LOGGER.debug("at_time (%s) in period [%s, %s[ of %s ending at %s,"
+            " %d days from renewal", at_time, lower, upper, subscription,
+            subscription.ends_at, days_from_end)
         if (upper == subscription.ends_at
             and (days_from_end >= 0 and days_from_end < 1)):
             # We are in the last day of the last period.
@@ -247,7 +252,7 @@ def trigger_expiration_notices(at_time=None, nb_days=15, dry_run=False):
                     if not dry_run:
                         signals.card_expires_soon.send(
                             sender=__name__, organization=organization,
-                            days=nb_days)
+                            nb_days=nb_days)
             except (KeyError, ValueError):
                 # exp info is missing or the format is incorrect
                 pass
@@ -299,7 +304,9 @@ def trigger_expiration_notices(at_time=None, nb_days=15, dry_run=False):
 
     # flushing the last organization
     if subscription and subscription.organization.id != prev_organization:
-        _handle_organization_notices(subscription.organization)
+        if subscription.auto_renew:
+            if subscription.plan.renewal_type == subscription.plan.AUTO_RENEW:
+                _handle_organization_notices(subscription.organization)
 
 
 def create_charges_for_balance(until=None, dry_run=False):
@@ -354,12 +361,14 @@ def create_charges_for_balance(until=None, dry_run=False):
                     except CardError as err:
                         # There was a problem with the Card (i.e. expired,
                         # underfunded, etc.)
+                        charge_processor_key = getattr(
+                            err, 'charge_processor_key', None)
                         LOGGER.info('FAILED CHARGE %d %s to %s (%s: %s)',
                             invoiceable_amount, invoiceable_unit,
-                            organization.slug, err.charge_processor_key,
-                            err,
-                            extra={'event': 'card-error',
-                                'charge': err.charge_processor_key,
+                            organization.slug, charge_processor_key,
+                            err, extra={
+                                'event': 'card-error',
+                                'charge': charge_processor_key,
                                 'detail': err.processor_details(),
                                 'organization': organization.slug,
                                 'amount': invoiceable_amount,
