@@ -2,6 +2,7 @@
 
 var DESC_SORT_PRE = '-';
 
+
 /** A wrapper around jQuery ajax functions that adds authentication
     parameters as necessary.
 
@@ -456,14 +457,14 @@ var httpRequestMixin = {
                 },
             }).done(successCallback).fail(failureCallback);
         },
-        /** This method generates a DELETE HTTP request to `url` with a query
-            string built of a `queryParams` dictionnary.
+        /** This method generates multiple queries, and execute
+            success/failure callbacks when all have completed.
 
             It supports the following prototypes:
 
-            - reqDELETE(url)
-            - reqDELETE(url, successCallback)
-            - reqDELETE(url, successCallback, failureCallback)
+            - reqMultiple(queryArray)
+            - reqMultiple(queryArray, successCallback)
+            - reqMultiple(queryArray, successCallback, failureCallback)
 
             `successCallback` and `failureCallback` must be Javascript
             functions (i.e. instance of type `Function`).
@@ -865,15 +866,5 @@ var itemListMixin = {
             }
             return result;
         },
-        humanizeTotal: function() {
-            var vm = this;
-            var filter = Vue.filter('humanizeCell');
-            return filter(vm.items.total, vm.items.unit, 0.01);
-        },
-        humanizeBalance: function() {
-            var vm = this;
-            var filter = Vue.filter('humanizeCell');
-            return filter(vm.items.balance_amount, vm.items.balance_unit, 0.01);
-        },
     },
 }
